#import "Beans.h"
#import <Foundation/Foundation.h>

/*
 Application-wide http request handling.
 Enables:
 - application-specific creation of requests, specifically:
 - addition of standard request headers
 - setting of standard request timeout
 - interception of responses before they're sent to their intended recipient
 
 The application might well want to subclass this and override some methods.
 */
@interface Requester : NSObject

- (NSMutableURLRequest*) createWithUrl:(NSURL*) url;
- (NSMutableURLRequest *) createWithString:(NSString *) url;

// Custom data stored in the URLLoader and returned at response time. Lets the requester store state against a request.
- (id) customData;

// Do something with a response before it gets to its intended receipient.
// Return NO if you don't want processing to continue for some reason. (This default implementation just returms YES.)
- (BOOL) onResponseReceived:(NSHTTPURLResponse *) response customData:(id) customData;

// Protected methods (these shouldn't be called directly - use the create methods)
// Override in application-specific subclass if you need to.
- (int) timeout;
- (void) addHeaders:(NSMutableURLRequest*) request;

@end
