#!/bin/sh

echo ==================== Uninstalling ===================== >&2
date >&2
id >&2

set -x

function status {
	log $*
}

# ------------------- The following section is shared with the installer. Keep them the same. ----------------------

logDir=/Library/Logs/FarSuite
dir="/Library/FarSuite"
olddir="/Library/Application Support/FarSuite"
appId=com.flyingmac.farsuite
daemonId=com.flyingmac.farsuite.daemon
appLaunchd=/Library/LaunchAgents/$appId.plist
daemonLaunchd=/Library/LaunchDaemons/$daemonId.plist
mainLog=$logDir/farsuite.log
username=$USER
filesDir=$dir/files
mainPrefs=$filesDir/main.plist
daemonPrefs=$filesDir/daemon.plist

function log {
	echo $* >&2
}

function killprocs() {
	targ=$1
	name=$2
	
	pids=`ps ax | fgrep "$targ" | grep -v grep | cut -c1-6`
	if [ ! -z "$pids" ]; then
		log "sending QUIT $name $pids"
		kill -QUIT $pids
		log "Waiting 5 seconds..."
		sleep 5
	fi
	pids=`ps ax | fgrep "$targ" | grep -v grep | cut -c1-6`
	if [ ! -z "$pids" ]; then
		log "sending HUP $name $pids"
		kill -HUP $pids
		log "Waiting 5 seconds..."
		sleep 5
	fi
	pids=`ps ax | fgrep "$targ" | grep -v grep | cut -c1-6`
	if [ ! -z "$pids" ]; then
		log "sending KILL $name $pids"
		kill -KILL $pids
		log "Waiting 5 seconds..."
		sleep 5
	fi
}

# Note this also needs to work when in the old location -  /Library/Application Support. 
# It does, as there's no dependency on installed location.
function stopEverything {
	# stop application
	if [ -f "$appLaunchd" ]; then
		status "Unloading application"
		sudo -u "$username" launchctl unload -S Aqua "$appLaunchd" &
		sleep 5
		kill %% || true
	else
		log "The application isn't in launchd"
	fi
	status "Checking for stray application"
	killprocs 'FarSuite.app/Contents/MacOS/FarSuite' Application


	# stop daemon
	if [ -f $daemonLaunchd ]; then
		status "Unloading daemon"
		launchctl unload /Library/LaunchDaemons/$daemonId.plist &
		sleep 5
		kill %% || true
	fi
	status "Checking for stray daemon"
	killprocs 'FarSuiteDaemon.app/Contents/MacOS/FarSuiteDaemon' Daemon
	
	# stop stray agents
	status "Checking for stray agents"
	killprocs "FarFinderAgent.app/Contents/MacOS/FarFinderAgent" FarFinderAgent
	killprocs "WebjimboAgent.app/Contents/MacOS/WebjimboAgent" WebjimboAgent
}

# ------------------- End installer shared section. ----------------------


stopEverything

rm "$appLaunchd"
rm "$daemonLaunchd"
rm -r "$dir"
rm /Library/Preferences/com.flyingmac.farsuite.plist # no longer used, but be tidy
rm /Library/Preferences/com.flyingmac.farsuite.daemon.plist # no longer used, but be tidy
rm -r /Library/Services/FarFinderServices.service
rm -r "/Library/Contextual Menu Items/FarFinderShare.bundle"
rm -r /Applications/FarFinder.app
rm -r /Applications/Presence.app
rm -r /Applications/Webjimbo.app
rm /Users/*/Library/Preferences/com.flyingmac.farfinder.client.plist
rm /Users/*/Library/Preferences/com.flyingmac.farfinder.plist
rm /Users/*/Library/Preferences/com.flyingmac.farfinder.sqlite
rm /Users/*/Library/Preferences/com.flyingmac.farsuite.plist
rm /Users/*/Library/Preferences/com.flyingmac.webjimbo.client.plist
rm /Users/*/Library/Keychains/FarFinder.keychain # no longer used, but be tidy
rm /Users/*/Library/Preferences/com.flyingmac.farfinder.auth
# Keep the logs. Lose too much info when people reinstall.
# rm -r $logDir
/System/Library/CoreServices/pbs
osascript <<END;
tell application "Finder"
	activate
	display dialog "Uninstall complete." buttons { "OK" }
end tell
END


